:orphan:

.. currentmodule:: obspy.clients.base
.. automodule:: obspy.clients.base

    .. comment to end block

    Classes & Functions
    -------------------
    .. autosummary::
       :toctree: autogen
       :nosignatures:

       ClientException
       ClientHTTPException
       BaseClient
       RemoteBaseClient
       HTTPClient
       WaveformClient
       EventClient
       StationClient

    .. comment to end block


